==> digikam_7.9.0.orig.tar.xz: digikam-7.9.0/core/dplugins/bqm/colors/colorbalance/colorbalanceplugin.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : a BQM plugin to fix colors balance
 *
 * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "colorbalanceplugin.h"

// Qt includes

#include <QPointer>
#include <QString>
#include <QApplication>

// KDE includes

#include <klocalizedstring.h>

// Local includes

#include "digikam_debug.h"
#include "colorbalance.h"

namespace DigikamBqmColorBalancePlugin
{

ColorBalancePlugin::ColorBalancePlugin(QObject* const parent)
    : DPluginBqm(parent)
{
}

ColorBalancePlugin::~ColorBalancePlugin()
{
}

QString ColorBalancePlugin::name() const
{
    return i18n("Color Balance");
}

QString ColorBalancePlugin::iid() const
{
    return QLatin1String(DPLUGIN_IID);
}

QIcon ColorBalancePlugin::icon() const
{
    return QIcon::fromTheme(QLatin1String("adjustrgb"));
}

QString ColorBalancePlugin::description() const
{
    return i18n("A tool to adjust color balance");
}

QString ColorBalancePlugin::details() const
{
    return i18n("<p>This Batch Queue Manager tool can adjust color balance from images.</p>");
}

QList<DPluginAuthor> ColorBalancePlugin::authors() const
{
    return QList<DPluginAuthor>()
            << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                             QString::fromUtf8("caulier dot gilles at gmail dot com"),
                             QString::fromUtf8("(C) 2010-2021"))
            ;
}

void ColorBalancePlugin::setup(QObject* const parent)
{
    ColorBalance* const tool = new ColorBalance(parent);
    tool->setPlugin(this);

    addTool(tool);
}

} // namespace DigikamBqmColorBalancePlugin

==> digikam_8.2.0.orig.tar.xz: digikam-8.2.0/core/dplugins/bqm/colors/colorbalance/colorbalanceplugin.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : a BQM plugin to fix colors balance
 *
 * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#include "colorbalanceplugin.h"

// Qt includes

#include <QPointer>
#include <QString>
#include <QApplication>

// KDE includes

#include <klocalizedstring.h>

// Local includes

#include "digikam_debug.h"
#include "colorbalance.h"

namespace DigikamBqmColorBalancePlugin
{

ColorBalancePlugin::ColorBalancePlugin(QObject* const parent)
    : DPluginBqm(parent)
{
}

ColorBalancePlugin::~ColorBalancePlugin()
{
}

QString ColorBalancePlugin::name() const
{
    return i18nc("@title", "Color Balance");
}

QString ColorBalancePlugin::iid() const
{
    return QLatin1String(DPLUGIN_IID);
}

QIcon ColorBalancePlugin::icon() const
{
    return QIcon::fromTheme(QLatin1String("adjustrgb"));
}

QString ColorBalancePlugin::description() const
{
    return i18nc("@info", "A tool to adjust color balance");
}

QString ColorBalancePlugin::details() const
{
    return xi18nc("@info", "<para>This Batch Queue Manager tool can adjust color balance from images.</para>");
}

QString ColorBalancePlugin::handbookSection() const
{
    return QLatin1String("batch_queue");
}

QString ColorBalancePlugin::handbookChapter() const
{
    return QLatin1String("base_tools");
}

QString ColorBalancePlugin::handbookReference() const
{
    return QLatin1String("bqm-colortools");
}

QList<DPluginAuthor> ColorBalancePlugin::authors() const
{
    return QList<DPluginAuthor>()
            << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                             QString::fromUtf8("caulier dot gilles at gmail dot com"),
                             QString::fromUtf8("(C) 2010-2022"))
            ;
}

void ColorBalancePlugin::setup(QObject* const parent)
{
    ColorBalance* const tool = new ColorBalance(parent);
    tool->setPlugin(this);

    addTool(tool);
}

} // namespace DigikamBqmColorBalancePlugin
